import React, { Fragment, useState } from 'react';
import { FieldLabel } from '../../forms/FieldLabel/index.js';
import { useForm } from '../../forms/Form/context.js';
import { createNestedClientFieldPath } from '../../forms/Form/createNestedFieldPath.js';
import { useTranslation } from '../../providers/Translation/index.js';
import { ReactSelect } from '../ReactSelect/index.js';
const baseClass = 'field-select';
const combineLabel = (prefix, field)=>{
    return /*#__PURE__*/ React.createElement(Fragment, null, /*#__PURE__*/ React.createElement("span", {
        style: {
            display: 'inline-block'
        }
    }, prefix), prefix ? /*#__PURE__*/ React.createElement(Fragment, null, ' > ') : '', /*#__PURE__*/ React.createElement("span", {
        style: {
            display: 'inline-block'
        }
    }, 'CustomLabel' in field.fieldComponentProps && field.fieldComponentProps.CustomLabel !== undefined ? field.fieldComponentProps.CustomLabel : /*#__PURE__*/ React.createElement(FieldLabel, 'labelProps' in field.fieldComponentProps && field.fieldComponentProps.labelProps || {})));
};
const reduceFields = (fieldMap, path = '', labelPrefix = null)=>{
    if (!fieldMap) {
        return [];
    }
    return fieldMap?.reduce((fieldsToUse, field)=>{
        const { isFieldAffectingData } = field;
        // escape for a variety of reasons
        if (isFieldAffectingData && (field.disableBulkEdit || field.unique || field.isHidden || 'readOnly' in field.fieldComponentProps && field.fieldComponentProps.readOnly)) {
            return fieldsToUse;
        }
        if (!(field.type === 'array' || field.type === 'blocks') && 'fieldMap' in field.fieldComponentProps) {
            return [
                ...fieldsToUse,
                ...reduceFields(field.fieldComponentProps.fieldMap, createNestedClientFieldPath(path, field), combineLabel(labelPrefix, field))
            ];
        }
        if (field.type === 'tabs' && 'fieldMap' in field.fieldComponentProps) {
            return [
                ...fieldsToUse,
                ...field.fieldComponentProps.fieldMap.reduce((tabFields, tab)=>{
                    if ('fieldMap' in tab.fieldComponentProps) {
                        return [
                            ...tabFields,
                            ...reduceFields(tab.fieldComponentProps.fieldMap, 'name' in tab && tab.name ? createNestedClientFieldPath(path, field) : path, combineLabel(labelPrefix, field))
                        ];
                    }
                }, [])
            ];
        }
        const formattedField = {
            label: combineLabel(labelPrefix, field),
            value: {
                ...field,
                path: createNestedClientFieldPath(path, field)
            }
        };
        return [
            ...fieldsToUse,
            formattedField
        ];
    }, []);
};
export const FieldSelect = ({ fieldMap, setSelected })=>{
    const { t } = useTranslation();
    const [options] = useState(()=>reduceFields(fieldMap));
    const { dispatchFields, getFields } = useForm();
    const handleChange = (selected)=>{
        const activeFields = getFields();
        if (selected === null) {
            setSelected([]);
        } else {
            setSelected(selected.map(({ value })=>value));
        }
        // remove deselected values from form state
        if (selected === null || Object.keys(activeFields || []).length > selected.length) {
            Object.keys(activeFields).forEach((path)=>{
                if (selected === null || !selected.find((field)=>{
                    return field.value.path === path;
                })) {
                    dispatchFields({
                        type: 'REMOVE',
                        path
                    });
                }
            });
        }
    };
    return /*#__PURE__*/ React.createElement("div", {
        className: baseClass
    }, /*#__PURE__*/ React.createElement(FieldLabel, {
        label: t('fields:selectFieldsToEdit')
    }), /*#__PURE__*/ React.createElement(ReactSelect, {
        isMulti: true,
        onChange: handleChange,
        options: options
    }));
};

//# sourceMappingURL=index.js.map