'use client';
import React from 'react';
import { HiddenInput } from '../../fields/HiddenInput/index.js';
import { useFieldComponents } from '../../providers/FieldComponents/index.js';
import { useOperation } from '../../providers/Operation/index.js';
import { FieldPropsProvider, useFieldProps } from '../FieldPropsProvider/index.js';
export const RenderField = ({ name, type, CustomField, disabled, fieldComponentProps, isHidden, path: pathFromProps, permissions, readOnly: readOnlyFromProps, schemaPath: schemaPathFromProps, siblingPermissions })=>{
    const operation = useOperation();
    const { readOnly: readOnlyFromContext } = useFieldProps();
    const fieldComponents = useFieldComponents();
    const path = `${pathFromProps ? `${pathFromProps}.` : ''}${name ? `${name}` : ''}`;
    const schemaPath = `${schemaPathFromProps ? `${schemaPathFromProps}` : ''}${name ? `.${name}` : ''}`;
    // if the user cannot read the field, then filter it out
    // this is different from `admin.readOnly` which is executed based on `operation`
    if (permissions?.read?.permission === false || disabled) {
        return null;
    }
    // `admin.readOnly` displays the value but prevents the field from being edited
    let readOnly = readOnlyFromProps;
    // if parent field is `readOnly: true`, but this field is `readOnly: false`, the field should still be editable
    if (readOnlyFromContext && readOnly !== false) readOnly = true;
    // if the user does not have access control to begin with, force it to be read-only
    if (permissions?.[operation]?.permission === false) {
        readOnly = true;
    }
    const DefaultField = isHidden ? HiddenInput : fieldComponents[type];
    if (CustomField === undefined && !DefaultField) {
        return null;
    }
    return /*#__PURE__*/ React.createElement(FieldPropsProvider, {
        path: path,
        permissions: permissions,
        readOnly: readOnly,
        schemaPath: schemaPath,
        siblingPermissions: siblingPermissions
    }, CustomField !== undefined ? CustomField : /*#__PURE__*/ React.createElement(DefaultField, fieldComponentProps));
};

//# sourceMappingURL=RenderField.js.map